package server;

import java.io.EOFException;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.StreamCorruptedException;
import java.util.Vector;

public class PersistMessageQueue {
	private static int capacity = 100;
	private static String queueFileNamePrefix = ".que";	

	private String queueName;
	

	protected PersistMessageQueue(String name) {
		queueName = name;
		

		initPersistStorage();

	}

	/**
	 * In case the queue has been created before, restore the queue state from
	 * the persist storage, i.e. a file. In case the queue has never been
	 * created, build persist storage for the queue
	 */
	private void initPersistStorage() {
		// to be implemented

	}

	
	/**
	 * Update the persistent storage when the data 
	 * or state of the queue is changed
	 */
	private void updatePersistStorage() {
		// to be implemented
	}

	/**
	 * Remove the persistent storage and all the related data when deleting the
	 * queue
	 */
	protected void destroyPersistStorage() {
		//to be implemented
	}

	/**
	 * return the queue name
	 */
	public String getName() {
		return queueName;
	}

	/**
	 * Get messages out of the FIFO Queue
	 * 
	 * @return null : if the queue is empty message
	 */
	public String dequeue() {
		// to be implemented
	}

	/**
	 * Add messages into the FIFO Queue
	 * 
	 * @param String
	 *            msg
	 * @return false : if the queue is full true : successfully add the message
	 */
	public boolean enqueue(String msg) {
		//to be implmented

	}

}
